.. _data-models:

===========
Data Models
===========

.. toctree::
   :maxdepth: 2

   models.rst
   attributes.rst
   metadata.rst
   new_model.rst
   structure.rst

.. automodapi:: jwst.datamodels
